==> medlogics-common-classes-1.1-20250915.071311-375.jar: com/floreantpos/services/InventoryService.java <==
package com.floreantpos.services;

import org.hibernate.Session;

import com.floreantpos.model.IUnit;
import com.floreantpos.model.InventoryStockUnit;
import com.floreantpos.model.InventoryUnit;
import com.floreantpos.model.MenuItem;
import com.floreantpos.model.Store;
import com.floreantpos.model.dao.InventoryStockUnitDAO;
import com.floreantpos.model.dao.MenuItemDAO;
import com.floreantpos.model.dao.TerminalDAO;
import com.floreantpos.model.util.DataProvider;

public class InventoryService {

	private static InventoryService instance;

	public static InventoryService getInstance() {
		if (instance == null) {
			instance = new InventoryService();
		}
		return instance;
	}

	private InventoryService() {
	}

	public void adjustMenuItemCost(MenuItem menuItem, double newCost, double newQuantity, InventoryUnit selectedUnit) {
		adjustMenuItemCost(menuItem, newCost, newCost, newQuantity, selectedUnit);
	}

	public void adjustMenuItemCost(MenuItem menuItem, double newCost, double unitPrice, double newQuantity, InventoryUnit selectedUnit) {
		MenuItemDAO.getInstance().refresh(menuItem);
		try (Session session = TerminalDAO.getInstance().createNewSession()) {
			this.adjustMenuItemCost(menuItem, newCost, unitPrice, newQuantity, selectedUnit, session);
		}
	}

	public void adjustMenuItemCost(MenuItem menuItem, double newCost, double unitPrice, double newQuantity, IUnit selectedUnit, Session session) {
		adjustMenuItemCost(menuItem, newCost, unitPrice, unitPrice, newQuantity, selectedUnit, session);
	}

	public void adjustMenuItemCost(MenuItem menuItem, double newUnitCost, double unitPrice, double mrpPrice, double newQuantity, IUnit selectedUnit,
			Session session) {
		Store store = DataProvider.get().getStore();
		if (store == null || menuItem == null || selectedUnit == null || session == null) {
			return;
		}
		Double menuItemOldCost = menuItem.getCost();
		//MenuItemDAO.getInstance().refresh(menuItem, session);
		double menuItemAverageCost = 0d;
		Double menuItemOnHand = menuItem.getUnitOnHand();
		if (menuItemOnHand < 0) {
			menuItemOnHand = 0.0;
		}
		if (selectedUnit instanceof InventoryUnit) {
			InventoryUnit baseUnit = menuItem.getUnit();

			if (selectedUnit != null && baseUnit != null && !baseUnit.equals(selectedUnit)) {
				Double selectedConversionRate = selectedUnit.getConversionRate();
				Double baseConversionRate = baseUnit.getConversionRate();
				newUnitCost = newUnitCost * (selectedConversionRate / baseConversionRate);
				newQuantity = newQuantity * menuItem.getUnitQuantity(selectedUnit, baseUnit);
			}
			menuItemAverageCost = (menuItemOnHand * menuItemOldCost + newQuantity * newUnitCost) / (menuItemOnHand + newQuantity);

		}
		else if (selectedUnit instanceof InventoryStockUnit) {
			InventoryStockUnit inventoryStockUnit = (InventoryStockUnit) selectedUnit;
			if (unitPrice > 0) {
				inventoryStockUnit.setPrice(unitPrice);
				if (newUnitCost > 0) {
					inventoryStockUnit.setCost(newUnitCost);
				}
				InventoryStockUnitDAO.getInstance().saveOrUpdate(inventoryStockUnit, session);
			}
			double baseItemUnitCost = newUnitCost / inventoryStockUnit.getConversionRate();
			menuItemAverageCost = (menuItemOnHand * menuItemOldCost + newQuantity * baseItemUnitCost) / (menuItemOnHand + newQuantity);
		}

		if (store.isInventoryAvgPricingMethod()) {
			if (menuItemAverageCost > 0) {
				menuItem.setCost(menuItemAverageCost);
			}
		}
		else {
			if (newUnitCost > 0) {
				menuItem.setCost(newUnitCost);
			}
		}

		menuItem.setLastPurchasedCost(newUnitCost);
		menuItem.setAverageUnitPurchasePrice(menuItemAverageCost);
	}
}

==> medlogics-common-classes-1.1-20251108.074021-449.jar: com/floreantpos/services/InventoryService.java <==
package com.floreantpos.services;

import java.util.List;

import org.hibernate.Session;

import com.floreantpos.model.IUnit;
import com.floreantpos.model.InventoryStockUnit;
import com.floreantpos.model.InventoryUnit;
import com.floreantpos.model.MenuItem;
import com.floreantpos.model.Store;
import com.floreantpos.model.dao.InventoryStockUnitDAO;
import com.floreantpos.model.dao.MenuItemDAO;
import com.floreantpos.model.dao.TerminalDAO;
import com.floreantpos.model.util.DataProvider;

public class InventoryService {

	private static InventoryService instance;

	public static InventoryService getInstance() {
		if (instance == null) {
			instance = new InventoryService();
		}
		return instance;
	}

	private InventoryService() {
	}

	public void adjustMenuItemCost(MenuItem menuItem, double newCost, double newQuantity, InventoryUnit selectedUnit) {
		adjustMenuItemCost(menuItem, newCost, newCost, newQuantity, selectedUnit);
	}

	public void adjustMenuItemCost(MenuItem menuItem, double newCost, double unitPrice, double newQuantity, InventoryUnit selectedUnit) {
		MenuItemDAO.getInstance().refresh(menuItem);
		try (Session session = TerminalDAO.getInstance().createNewSession()) {
			this.adjustMenuItemCost(menuItem, newCost, unitPrice, newQuantity, selectedUnit, session);
		}
	}

	public void adjustMenuItemCost(MenuItem menuItem, double newCost, double unitPrice, double newQuantity, IUnit selectedUnit, Session session) {
		adjustMenuItemCost(menuItem, newCost, unitPrice, unitPrice, newQuantity, selectedUnit, session);
	}

	public void adjustMenuItemCost(MenuItem menuItem, double newUnitCost, double unitPrice, double mrpPrice, double newQuantity, IUnit selectedUnit,
			Session session) {
		Store store = DataProvider.get().getStore();
		if (store == null || menuItem == null || selectedUnit == null || session == null) {
			return;
		}
		Double menuItemOldCost = menuItem.getCost();
		//MenuItemDAO.getInstance().refresh(menuItem, session);
		double menuItemAverageCost = 0d;
		Double menuItemOnHand = menuItem.getUnitOnHand();
		if (menuItemOnHand < 0) {
			menuItemOnHand = 0.0;
		}
		if (selectedUnit instanceof InventoryUnit) {
			InventoryUnit baseUnit = menuItem.getUnit();

			if (selectedUnit != null && baseUnit != null && !baseUnit.equals(selectedUnit)) {
				Double selectedConversionRate = selectedUnit.getConversionRate();
				Double baseConversionRate = baseUnit.getConversionRate();
				newUnitCost = newUnitCost * (selectedConversionRate / baseConversionRate);
				newQuantity = newQuantity * menuItem.getUnitQuantity(selectedUnit, baseUnit);
			}
			menuItemAverageCost = (menuItemOnHand * menuItemOldCost + newQuantity * newUnitCost) / (menuItemOnHand + newQuantity);

		}
		else if (selectedUnit instanceof InventoryStockUnit) {
			InventoryStockUnit inventoryStockUnit = (InventoryStockUnit) selectedUnit;
			if (unitPrice > 0) {
				inventoryStockUnit.setPrice(unitPrice);
				if (newUnitCost > 0) {
					inventoryStockUnit.setCost(newUnitCost);
					List<InventoryStockUnit> stockUnits = menuItem.getStockUnits();
					if (stockUnits != null && stockUnits.size() > 0) {
						for (InventoryStockUnit stockUnit : stockUnits) {
							if (stockUnit.getCost() == 0 && stockUnit.getId() != null && !stockUnit.getId().equals(inventoryStockUnit.getId())) {
								Double baseUnitCost = newUnitCost / selectedUnit.getConversionRate();
								Double stockUnitCost = baseUnitCost * stockUnit.getConversionRate();
								stockUnit.setCost(stockUnitCost);
								InventoryStockUnitDAO.getInstance().saveOrUpdate(stockUnit, session);
							}
						}
					}
				}
				InventoryStockUnitDAO.getInstance().saveOrUpdate(inventoryStockUnit, session);
			}
			double baseItemUnitCost = newUnitCost / inventoryStockUnit.getConversionRate();
			menuItemAverageCost = (menuItemOnHand * menuItemOldCost + newQuantity * baseItemUnitCost) / (menuItemOnHand + newQuantity);
		}

		if (store.isInventoryAvgPricingMethod()) {
			if (menuItemAverageCost > 0) {
				menuItem.setCost(menuItemAverageCost);
			}
		}
		else {
			if (newUnitCost > 0) {
				menuItem.setCost(newUnitCost);
			}
		}

		menuItem.setLastPurchasedCost(newUnitCost);
		menuItem.setAverageUnitPurchasePrice(menuItemAverageCost);
	}
}
